@@ -105,10 +105,10 @@ impl DataPageHeader {
 /// and thus cloning it is expensive.
 #[derive(Debug, Clone)]
 pub struct DataPage {
-    header: DataPageHeader,
+    pub(super) header: DataPageHeader,
     pub(super) buffer: Vec<u8>,
-    dictionary_page: Option<Arc<dyn DictPage>>,
-    descriptor: ColumnDescriptor,
+    pub(super) dictionary_page: Option<Arc<dyn DictPage>>,
+    pub(super) descriptor: ColumnDescriptor,
 }
 
 impl DataPage {
@@ -138,6 +138,12 @@ impl DataPage {
         &self.buffer
     }
 
+    /// Returns a mutable reference to the internal buffer.
+    /// Useful to recover the buffer after the page has been decoded.
+    pub fn buffer_mut(&mut self) -> &mut Vec<u8> {
+        &mut self.buffer
+    }
+
     pub fn num_values(&self) -> usize {
         self.header.num_values()
     }
@@ -190,6 +196,14 @@ pub enum Page {
     Dict(Arc<dyn DictPage>),
 }
 
+/// A [`EncodedPage`] is an uncompressed, encoded representation of a Parquet page. It may hold actual data
+/// and thus cloning it may be expensive.
+#[derive(Debug)]
+pub enum EncodedPage {
+    Data(DataPage),
+    Dict(EncodedDictPage),
+}
+
 /// A [`CompressedPage`] is a compressed, encoded representation of a Parquet page. It holds actual data
 /// and thus cloning it is expensive.
 #[derive(Debug)]
@@ -198,6 +212,15 @@ pub enum CompressedPage {
     Dict(CompressedDictPage),
 }
 
+impl CompressedPage {
+    pub(crate) fn buffer(&mut self) -> &mut Vec<u8> {
+        match self {
+            CompressedPage::Data(page) => &mut page.buffer,
+            CompressedPage::Dict(page) => &mut page.buffer,
+        }
+    }
+}
+
 /// Splits the page buffer into 3 slices corresponding to (encoded rep levels, encoded def levels, encoded values) for v1 pages.
 #[inline]
 pub fn split_buffer_v1(buffer: &[u8], has_rep: bool, has_def: bool) -> (&[u8], &[u8], &[u8]) {
