@@ -1,9 +1,9 @@
+use std::io::Write;
+
 use futures::stream::Stream;
 use futures::StreamExt;
 use futures::TryStreamExt;
 
-use std::{error::Error, io::Write};
-
 use parquet_format_async_temp::FileMetaData;
 
 pub use crate::metadata::KeyValue;
@@ -26,7 +26,8 @@ pub async fn write_stream<'a, W, S, E>(
 where
     W: Write,
     S: Stream<Item = std::result::Result<RowGroupIter<'a, E>, E>>,
-    E: Error + Send + Sync + 'static,
+    ParquetError: From<E>,
+    E: std::error::Error,
 {
     let mut offset = start_file(writer)? as u64;
 
@@ -37,7 +38,7 @@ where
                 offset,
                 schema.columns(),
                 options.compression,
-                row_group.map_err(ParquetError::from_external_error)?,
+                row_group?,
             )?;
             offset += size;
             Result::Ok(group)
